@@ -34,6 +34,7 @@ def parse_args(action, usage):
     parser.add_argument("--extra-media-data", default={}, nargs=1, action=utils.argparse_dict, metavar="KEY=VALUE")
     parser.add_argument("--extra-playlist-data", default={}, nargs=1, action=utils.argparse_dict, metavar="KEY=VALUE")
     parser.add_argument("--ignore-errors", "--ignoreerrors", "-i", action="store_true", help=argparse.SUPPRESS)
+    parser.add_argument("--safe", "-safe", action="store_true", help="Skip generic URLs")
 
     parser.add_argument("--prefix", default=os.getcwd(), help=argparse.SUPPRESS)
     parser.add_argument("--ext", default="DEFAULT")
@@ -71,6 +72,7 @@ def parse_args(action, usage):
         args.database = args.db
     args.db = db.connect(args)
 
+    args.playlists = utils.conform(args.playlists)
     log.info(utils.dict_filter_bool(args.__dict__))
 
     return args
@@ -116,6 +118,8 @@ def construct_query(args) -> Tuple[str, dict]:
             and time_downloaded=0
             and media.time_deleted=0
             and p.time_deleted=0
+            {'AND (score IS NULL OR score > 7)' if 'score' in m_columns else ''}
+            {'AND (upvote_ratio IS NULL OR upvote_ratio > 0.73)' if 'upvote_ratio' in m_columns else ''}
             {args.sql_filter}
             and media.uploader not in (select uploader from playlists where category='{consts.BLOCK_THE_CHANNEL}')
         ORDER BY 1=1
@@ -191,6 +195,10 @@ def dl_download(args=None) -> None:
     )
     media = process_downloadqueue(args)
     for m in media:
+        if args.safe and not tube_backend.is_supported(m["path"]):
+            log.warning("[%s]: Unsupported URL (safe_mode)", m["path"])
+            continue
+
         # check again in case it was already completed by another process
         path = list(args.db.query("select path from media where path=?", [m["path"]]))
         if not path:
