@@ -86,7 +86,7 @@ def extract_chunk(args, chunk_paths) -> None:
             p.unlink()
 
     media = list(filter(None, metadata))
-    args.db["media"].insert_all(media, pk="path", alter=True, replace=True)
+    args.db["media"].insert_all(utils.list_dict_filter_bool(media), pk="path", alter=True, replace=True)
 
 
 def find_new_files(args, path: Path) -> List[str]:
@@ -143,13 +143,13 @@ def _add_folder(args, folder_path: Path) -> None:
     playlist = {
         "ie_key": "Local",
         "path": str(folder_path),
-        "dl_config": utils.get_config_opts(args, ["ocr", "speech_recognition", "scan_subtitles"]),
+        "config": utils.get_config_opts(args, ["ocr", "speech_recognition", "scan_subtitles"]),
         "time_deleted": 0,
         "category": category,
         "profile": args.profile,
         **args.extra_playlist_data,
     }
-    args.db["playlists"].upsert(playlist, pk="path", alter=True)
+    args.db["playlists"].upsert(utils.dict_filter_bool(playlist), pk="path", alter=True)
 
 
 def scan_path(args, path_str: str) -> int:
@@ -284,6 +284,7 @@ def parse_args() -> argparse.Namespace:
         args.database = args.db
     Path(args.database).touch()
     args.db = db.connect(args)
+    args.paths = utils.conform(args.paths)
     log.info(utils.dict_filter_bool(args.__dict__))
 
     return args
